<?php

namespace CRPlugins\Oca\Helper;

use ZipArchive;

trait FilesTrait {

	use LoggerTrait;
	use AssetsTrait;

	public static function create_zip( string $zip_name, array $files ): void {
		$zip      = new ZipArchive();
		$zip_name = sprintf( '%s/%s.zip', Helper::get_labels_folder_path(), $zip_name );

		// Override old zip
		if ( file_exists( $zip_name ) ) {
			unlink( $zip_name );
		}

		$zip->open( $zip_name, ZipArchive::CREATE );
		foreach ( $files as $file ) {
			$zip->addFile( $file, basename( $file ) );
		}

		$zip->close();
	}

	public static function get_zip_url( string $zip_name ): string {
		return sprintf( '%s/%s.zip', Helper::get_labels_folder_url(), $zip_name );
	}

	public static function create_merged_pdf( array $pdfs_names ): string {
		require_once AssetsTrait::get_libs_folder_path() . '/OcaConcatPdf.php';
		$pdf_merger = new \OcaConcatPdf();

		foreach ( $pdfs_names as $pdf_name ) {
			$pdf_merger->addFile( sprintf( '%s/%s', AssetsTrait::get_labels_folder_path(), $pdf_name ) );
		}
		$pdf_merger->concat();

		$now             = new \DateTime();
		$final_file_name = sprintf( 'merge-%s', $now->format( 'U' ) );
		$final_path      = sprintf( '%s/%s.pdf', AssetsTrait::get_labels_folder_path(), $final_file_name );

		$pdf_merger->Output( $final_path, 'F' );
		$content = file_get_contents( $final_path );
		unlink( $final_path );

		return $content;
	}
}
