<?php

namespace CRPlugins\Oca\Orders;

use CRPlugins\Oca\Helper\Helper;
use CRPlugins\Oca\Sdk\OcaSdk;
use CRPlugins\Oca\ValueObjects\Customer;
use CRPlugins\Oca\ValueObjects\Items;
use CRPlugins\Oca\ValueObjects\Seller;
use CRPlugins\Oca\ValueObjects\ShippingCodes;
use WC_Order;

defined( 'ABSPATH' ) || exit;

class Quoter {

	/**
	 * @var OcaSdk
	 */
	private $oca_sdk;

	public function __construct() {
		add_action( 'wp_ajax_oca_get_shipping_label_pdf', array( $this, 'get_shipping_label_pdf' ) );
		add_action( 'wp_ajax_oca_get_shipping_label_zpl', array( $this, 'get_shipping_label_zpl' ) );
		add_action( 'wp_ajax_oca_get_multiple_shipping_labels_pdf', array( $this, 'get_multiple_shipping_labels_pdf' ) );
		add_action( 'wp_ajax_oca_download_multiple_shipping_labels_pdf', array( $this, 'download_multiple_shipping_labels_pdf' ) );
		add_action( 'wp_ajax_oca_download_multiple_shipping_labels_zpl', array( $this, 'download_multiple_shipping_labels_zpl' ) );
		add_action( 'wp_ajax_oca_get_order_tracking', array( $this, 'get_order_tracking' ) );
		add_action( 'wp_ajax_oca_process_order', array( $this, 'process_order' ) );
		add_action( 'wp_ajax_oca_cancel_order', array( $this, 'cancel_order' ) );
		add_action( 'wp_ajax_oca_update_order_packages_number', array( $this, 'update_order_packages_number' ) );
		add_action( 'wp_ajax_oca_requote_order', array( $this, 'requote_order' ) );

		$this->oca_sdk = new OcaSdk();
		$this->oca_sdk->set_data( Helper::get_seller_from_settings() );
	}

	public function quote_cart( Items $items, Seller $seller, $destination, ShippingCodes $shipping_codes ): array {
		$this->oca_sdk->set_shipping_codes( $shipping_codes->get_codes() );

		if ( is_array( $destination ) ) {
			$destination = $destination['postcode']; // to branch, use branch array
		} else {
			/** @var Customer $destination */
			$destination = $destination->address()->postcode(); // to door, uses Customer
			/** @var string $destination */
		}

		return $this->oca_sdk->get_price(
			$items->totals(),
			$seller->get_address()->get_postcode(),
			$destination
		);
	}

	public function get_shipping_branches_to( string $postcode ): array {
		return $this->oca_sdk->get_shipping_branches_to( $postcode );
	}

	public function quote_order( WC_Order $order ): array {
		$shipping_method = Helper::get_order_shipping_method( $order );
		if ( ! Helper::shipping_method_is_oca( $shipping_method ) ) {
			return array();
		}

		$shipping_code = $shipping_method->get_meta( 'shipping_code' );
		if ( ! $shipping_code ) {
			return array();
		}

		if ( 'PaS' === $shipping_code['type'] || 'SaS' === $shipping_code['type'] ) {
			return array();
		}

		$this->oca_sdk->set_shipping_codes( array( $shipping_code['code'] ) );

		$items    = Helper::get_items_from_order( $order );
		$seller   = Helper::get_seller_from_settings();
		$customer = Helper::get_order_customer( $order );

		return $this->oca_sdk->get_price( $items->totals(), $seller->get_address()->get_postcode(), $customer->address()->postcode() );
	}
}
