<?php

namespace CRPlugins\Oca\Settings;

use CRPlugins\Oca\Settings\Fields\AjaxButtonField;
use CRPlugins\Oca\Settings\Fields\CheckboxField;
use CRPlugins\Oca\Settings\Fields\DescriptionField;
use CRPlugins\Oca\Settings\Fields\NumberField;
use CRPlugins\Oca\Settings\Fields\OcaShippingCodesField;
use CRPlugins\Oca\Settings\Fields\PasswordField;
use CRPlugins\Oca\Settings\Fields\SelectField;
use CRPlugins\Oca\Settings\Fields\TextField;

/**
 * This factory creates a FieldInterface
 */
class FieldFactory {


	/**
	 * Creates a Field
	 *
	 * @param string $slug
	 * @return FieldInterface|false
	 */
	public function create( string $slug ) {
		$fields = Main::get_settings_fields();
		if ( empty( $fields[ $slug ] ) ) {
			return false;
		}
		switch ( $fields[ $slug ]['type'] ) {
			case 'text':
				$field = new TextField( $fields[ $slug ] );
				break;
			case 'checkbox':
				$field = new CheckboxField( $fields[ $slug ] );
				break;
			case 'select':
				$field = new SelectField( $fields[ $slug ] );
				break;
			case 'number':
				$field = new NumberField( $fields[ $slug ] );
				break;
			case 'description':
				$field = new DescriptionField( $fields[ $slug ] );
				break;
			case 'password':
				$field = new PasswordField( $fields[ $slug ] );
				break;
			case 'ocashippingcodes':
				$field = new OcaShippingCodesField( $fields[ $slug ] );
				break;
			case 'ajaxbutton':
				$field = new AjaxButtonField( $fields[ $slug ] );
				break;
			default:
				$field = false;
		}
		return $field;
	}
}
