<?php

namespace CRPlugins\Oca\Settings;

defined( 'ABSPATH' ) || exit;

/**
 * Class which will handle our settings being saved
 */
class FieldsVerifier {

	public static function save_settings( array $post_data, array &$errors ): bool {
		$saved           = false;
		$settings_fields = Main::get_settings_fields();
		foreach ( $settings_fields as $setting ) {
			if ( ! isset( $post_data[ $setting['slug'] ] ) ) {
				continue;
			}
			$value = $post_data[ $setting['slug'] ];
			if ( ! is_array( $value ) ) {
				$value = wp_strip_all_tags( sanitize_text_field( $value ) );
			}
			if ( ! empty( $setting['regexmask'] ) ) {
				if ( preg_match( $setting['regexmask'], $value, $res ) === 0 ) {
					$errors[] = sprintf( __( 'Value given for field <b>%s</b> is invalid, please use a valid format', 'wc-oca' ), $setting['name'] );
					continue;
				}
			}
			update_option( 'wc-oca-' . $setting['slug'], $value );
			$saved = true;
		}
		return $saved;
	}
}
