<?php

namespace CRPlugins\Oca\ShippingMethod;

use CRPlugins\Oca\Helper\Helper;

defined( 'ABSPATH' ) || exit;

class ShippingBranchHelper {

	public function __construct() {
		add_action( 'woocommerce_before_cart_totals', array( $this, 'enqueue_oca_branches_js' ) );
		add_action( 'woocommerce_before_checkout_form', array( $this, 'enqueue_oca_branches_js' ) );

		add_action( 'woocommerce_after_shipping_rate', array( $this, 'show_branches_selection' ), 10, 2 );
		if ( Helper::is_enabled( 'enable_branch_selector' ) ) {
			add_filter( 'woocommerce_shipping_packages', array( $this, 'clear_cache' ) );
		}
	}

	public function enqueue_oca_branches_js() {
		wp_enqueue_script( 'wc-oca-cho-branches-dropdown-js' );
		wp_localize_script(
			'wc-oca-cho-branches-dropdown-js',
			'wc_oca_settings',
			array(
				'ajax_url'               => admin_url( 'admin-ajax.php' ),
				'ajax_nonce'             => wp_create_nonce( 'wc-oca' ),
				'output_location'        => '#shipping_method',
				'chosen_shipping_branch' => WC()->session->get( 'wc_oca_selected_shipping_branch', '' ),
				'page_is_checkout'       => is_checkout(),
				'page_is_cart'           => is_cart(),
				'page_is_single_product' => is_product(),
			)
		);
		wp_localize_script(
			'wc-oca-cho-branches-dropdown-js',
			'wc_oca_translation_texts',
			array(
				'generic_error_try_again' => __( 'There was an error, please try again', 'wc-oca' ),
			)
		);
	}

	public function show_branches_selection( \WC_Shipping_Rate $current_rate, int $index ) {
		global $oca_already_printed_selector, $oca_cart_sb;

		if ( ! empty( $oca_already_printed_selector ) || empty( $oca_cart_sb ) ) {
			return;
		}

		// Check for current shipping method in the loop
		if ( ! Helper::cart_method_is_oca( $current_rate->get_id() )['branch'] ) {
			return;
		}

		// Check if the chosen method is OCA
		$chosen_methods = WC()->session->get( 'chosen_shipping_methods' );
		if ( empty( $chosen_methods[0] ) || ! Helper::cart_method_is_oca( $chosen_methods[0] )['branch'] ) {
			return;
		}

		// Filter branches for COD, otherwise we get error when processing
		$branches_to_print = $oca_cart_sb;

		$customer_postcode = WC()->customer->get_shipping_postcode();
		if ( empty( $customer_postcode ) ) {
			// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			echo $this->no_address();
			return;
		}

		$selected_branch = WC()->session->get( 'wc_oca_selected_shipping_branch', '{}' );
		$selected_branch = json_decode( $selected_branch, true );
		// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		echo $this->branches_as_dropdown( $branches_to_print, $selected_branch );
		if ( empty( $oca_already_printed_selector ) ) {
			$oca_already_printed_selector = true;
		}
	}

	public function no_address(): string {
		$output  = '<span class="oca-no-customer-address-message">';
		$output .= esc_html_e( 'Please fill your shipping information to view the shipping branches near your area', 'wc-oca' );
		$output .= '</span>';
		return $output;
	}

	public function branches_as_dropdown( array $branches, array $selected = array() ): string {
		$output  = '<div id="oca-branches-selection-wrapper">';
		$output .= '<p class="oca-select-office-message" style="margin:10px 0 0 0;display:block;font-size:85%;">' . __( 'Select a OCA shipping branch for your order', 'wc-oca' ) . '</p>';
		$output .= '<select id="oca_shipping_branch_selection" style="margin:15px 0; width: 100%;" required>';
		if ( ! empty( $selected ) ) {
			$output .= '<option disabled>Seleccionar</option>';
			foreach ( $branches as $branch ) {
				$opt_selected = ( $branch['IdCentroImposicion'] === $selected['id'] ? 'selected' : '' );
				$output      .= sprintf(
					'<option value="%s" data-postcode="%d" %s> %s %s, %s %s</option>',
					esc_attr( $branch['IdCentroImposicion'] ),
					esc_attr( $branch['CodigoPostal'] ),
					esc_attr( $opt_selected ),
					esc_html( $branch['Calle'] ),
					esc_html( $branch['Numero'] ),
					esc_html( $branch['Localidad'] ),
					esc_html( $branch['CodigoPostal'] )
				);
			}
		} else {
			$output .= '<option selected disabled>Seleccionar</option>';
			foreach ( $branches as $branch ) {
				$output .= sprintf(
					'<option value="%s" data-postcode="%d"> %s %s, %s %s</option>',
					esc_attr( $branch['IdCentroImposicion'] ),
					esc_attr( $branch['CodigoPostal'] ),
					esc_html( $branch['Calle'] ),
					esc_html( $branch['Numero'] ),
					esc_html( $branch['Localidad'] ),
					esc_html( $branch['CodigoPostal'] )
				);
			}
		}
		$output .= '</select>';
		$output .= '</div>';
		return $output;
	}

	public static function select_first_branch( array $branches ): array {
		$branch          = array_shift( $branches );
		$selected_branch = array(
			'id'       => $branch['IdCentroImposicion'],
			'name'     => "{$branch['Calle']} {$branch['Numero']}, {$branch['Localidad']} {$branch['CodigoPostal']}",
			'postcode' => $branch['CodigoPostal'],
		);
		WC()->session->set( 'wc_oca_selected_shipping_branch', wp_json_encode( $selected_branch ) );
		return $selected_branch;
	}

	public static function is_same_branch_request( string $postcode ): bool {
		$last_branch_request = WC()->session->get( 'wc_oca_last_shipping_branch_request', '0' );
		if ( empty( $last_branch_request ) || $last_branch_request !== $postcode ) {
			return false;
		}
		return true;
	}

	public static function clear_cache( array $packages ): array {
		foreach ( $packages as $key => $value ) {
			$shipping_session = "shipping_for_package_$key";
			unset( WC()->session->$shipping_session );
		}
		return $packages;
	}
}
