<?php

namespace CRPlugins\Oca\ValueObjects;

class Customer {

	/**
	 * @var string
	 */
	private $first_name;
	/**
	 * @var string
	 */
	private $last_name;
	/**
	 * @var CustomerAddress
	 */
	private $address;
	/**
	 * @var string
	 */
	private $email;
	/**
	 * @var string
	 */
	private $phone;
	/**
	 * @var string
	 */
	private $extra_info;
	/**
	 * @var string
	 */
	private $shipping_branch;

	public function __construct(
		string $first_name,
		string $last_name,
		string $street,
		string $number,
		string $floor,
		string $apartment,
		string $postcode,
		string $city,
		string $state,
		string $email = '',
		string $phone = '',
		string $extra_info = '',
		string $shipping_branch = '0'
	) {
		$this->first_name      = $first_name;
		$this->last_name       = $last_name;
		$this->address         = new CustomerAddress(
			$street,
			$number,
			$floor,
			$apartment,
			$postcode,
			$city,
			$state
		);
		$this->email           = $email;
		$this->phone           = $phone;
		$this->extra_info      = $extra_info;
		$this->shipping_branch = $shipping_branch;
	}

	public function set_email( string $email ): void {
		$this->email = $email;
	}

	public function set_phone( string $phone ): void {
		$this->phone = $phone;
	}

	public function set_extra_info( string $extra_info ): void {
		$this->extra_info = $extra_info;
	}

	public function set_shipping_branch( string $shipping_branch ): void {
		$this->shipping_branch = $shipping_branch;
	}

	public function to_array(): array {
		return array(
			'first_name'      => $this->first_name(),
			'last_name'       => $this->last_name(),
			'full_name'       => $this->full_name(),
			'street'          => $this->address()->street(),
			'number'          => $this->address()->number(),
			'floor'           => $this->address()->floor(),
			'apartment'       => $this->address()->apartment(),
			'full_address'    => $this->address()->full_address(),
			'postcode'        => $this->address()->postcode(),
			'city'            => $this->address()->city(),
			'state'           => $this->address()->state(),
			'email'           => $this->email(),
			'phone'           => $this->phone(),
			'extra_info'      => $this->extra_info(),
			'shipping_branch' => $this->shipping_branch(),
		);
	}

	public function first_name(): string {
		return $this->first_name;
	}

	public function last_name(): string {
		return $this->last_name;
	}

	public function full_name(): string {
		return sprintf(
			'%s %s',
			$this->first_name(),
			$this->last_name()
		);
	}

	public function address(): CustomerAddress {
		return $this->address;
	}

	public function email(): string {
		return $this->email;
	}

	public function phone(): string {
		return $this->phone;
	}

	public function extra_info(): string {
		return $this->extra_info;
	}

	public function shipping_branch(): string {
		return $this->shipping_branch;
	}
}
