<?php

namespace CRPlugins\Oca\ValueObjects;

class Seller {

	/**
	 * @var string
	 */
	private $username;

	/**
	 * @var string
	 */
	private $password;

	/**
	 * @var string
	 */
	private $account_number;

	/**
	 * @var string
	 */
	private $cuit;

	/**
	 * @var ShippingCodes
	 */
	private $shipping_codes;

	/**
	 * @var SellerAddress
	 */
	private $address;

	public function __construct( array $settings ) {
		$this->username       = $settings['username'];
		$this->password       = $settings['password'];
		$this->account_number = $settings['accountNumber'];
		$this->cuit           = $settings['cuit'];
		$this->shipping_codes = ShippingCodes::create_from_array( $settings['shippingCodes'] );
		$this->address        = new SellerAddress(
			$settings['street'],
			$settings['streetNumber'],
			$settings['floor'],
			$settings['apartment'],
			$settings['postcode'],
			$settings['city'],
			$settings['state'],
			$settings['name'],
			$settings['email'],
			$settings['storeName'],
			$settings['observations'],
			$settings['timeFrame'],
			$settings['shippingBranch']
		);
	}

	public function get_username(): string {
		return $this->username;
	}

	public function get_password(): string {
		return base64_encode( $this->password );
	}

	public function get_account_number(): string {
		return $this->account_number;
	}

	public function get_cuit(): string {
		return $this->cuit;
	}

	public function get_shipping_codes(): ShippingCodes {
		return $this->shipping_codes;
	}

	public function get_address(): SellerAddress {
		return $this->address;
	}
}
