<?php

namespace CRPlugins\Oca\ValueObjects;

class ShippingCodes {

	/**
	 * @var ShippingCode[]
	 */
	private $shipping_codes;

	private function __construct() {
		$this->shipping_codes = array();
	}

	public static function create( array $shipping_codes ): self {
		$object = new self();

		$object->shipping_codes = $shipping_codes;
		return $object;
	}

	public static function create_from_array( array $shipping_codes ): self {
		$object = new self();

		$object->shipping_codes = array_map(
			function( $shipping_code ) {
				return new ShippingCode(
					$shipping_code['id'],
					$shipping_code['name'],
					$shipping_code['type'],
					! empty( $shipping_code['price'] ) ? $shipping_code['price'] : 0
				);
			},
			$shipping_codes
		);
		return $object;
	}

	/**
	 * @return ShippingCode[]
	 */
	public function all(): array {
		return $this->shipping_codes;
	}

	public function to_branch(): ShippingCodes {
		return self::create(
			array_filter(
				$this->shipping_codes,
				function( ShippingCode $shipping_code ) {
					return $shipping_code->get_type() === 'PaS' || $shipping_code->get_type() === 'SaS';
				}
			)
		);
	}

	public function to_door(): ShippingCodes {
		return self::create(
			array_filter(
				$this->shipping_codes,
				function( ShippingCode $shipping_code ) {
					return $shipping_code->get_type() === 'PaP' || $shipping_code->get_type() === 'SaP';
				}
			)
		);
	}

	public function with_price(): ShippingCodes {
		return self::create(
			array_filter(
				$this->shipping_codes,
				function( ShippingCode $shipping_code ) {
					return $shipping_code->has_price();
				}
			)
		);
	}

	public function without_price(): ShippingCodes {
		return self::create(
			array_filter(
				$this->shipping_codes,
				function( ShippingCode $shipping_code ) {
					return ! $shipping_code->has_price();
				}
			)
		);
	}

	public function get_by_code( string $code ): ?ShippingCode {
		foreach ( $this->shipping_codes as $shipping_code ) {
			if ( $code === $shipping_code->get_code() ) {
				return $shipping_code;
			}
		}

		return null;
	}

	public function get_codes(): array {
		return array_map(
			function( ShippingCode $shipping_code ) {
				return $shipping_code->get_code();
			},
			$this->shipping_codes
		);
	}
}
